<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About KeePassX</source>
        <translation>Sobre KeePassX</translation>
    </message>
    <message>
        <source>KeePassX is distributed under the term of the GNU General Public License (GPL) version 2 or (at your option) version 3.</source>
        <translation>KeePassX é distribuído nos termos da Licença Pública Geral (GPL), versão 2 ou (à sua escolha) versão 3, do GNU.</translation>
    </message>
    <message>
        <source>Revision</source>
        <translation>Revisão</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>Usando:</translation>
    </message>
</context>
<context>
    <name>AutoType</name>
    <message>
        <source>Auto-Type - KeePassX</source>
        <translation>Auto-Digitação - KeePassX</translation>
    </message>
    <message>
        <source>Couldn&apos;t find an entry that matches the window title:</source>
        <translation>Não foi possível localizar uma entrada que corresponda ao título da janela:</translation>
    </message>
</context>
<context>
    <name>AutoTypeAssociationsModel</name>
    <message>
        <source>Window</source>
        <translation>Janela</translation>
    </message>
    <message>
        <source>Sequence</source>
        <translation>Sequência</translation>
    </message>
    <message>
        <source>Default sequence</source>
        <translation>Sequência pré-definida</translation>
    </message>
</context>
<context>
    <name>AutoTypeSelectDialog</name>
    <message>
        <source>Auto-Type - KeePassX</source>
        <translation>Auto-Digitação - KeePassX</translation>
    </message>
    <message>
        <source>Select entry to Auto-Type:</source>
        <translation>Escolha uma entrada para Auto-Digitar:</translation>
    </message>
</context>
<context>
    <name>ChangeMasterKeyWidget</name>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <source>Enter password:</source>
        <translation>Insira senha:</translation>
    </message>
    <message>
        <source>Repeat password:</source>
        <translation>Repita senha:</translation>
    </message>
    <message>
        <source>Key file</source>
        <translation>Arquivo-Chave</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Navegar</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Criar</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>Arquivos-Chave</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Todos os Arquivos</translation>
    </message>
    <message>
        <source>Create Key File...</source>
        <translation>Criar Arquivo-Chave...</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Unable to create Key File : </source>
        <translation>Não foi possível criar o Arquivo-Chave : </translation>
    </message>
    <message>
        <source>Select a key file</source>
        <translation>Escolha um arquivo-chave</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pergunta</translation>
    </message>
    <message>
        <source>Do you really want to use an empty string as password?</source>
        <translation>Você realmente quer usar uma sequência vazia como senha?</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>Senhas diferentes fornecidas.</translation>
    </message>
    <message>
        <source>Failed to set key file</source>
        <translation>Falha ao definir arquivo-chave</translation>
    </message>
    <message>
        <source>Failed to set %1 as the Key file:
%2</source>
        <translation>Falha ao definir %1 como o Arquivo-Chave:
%2</translation>
    </message>
</context>
<context>
    <name>DatabaseOpenWidget</name>
    <message>
        <source>Enter master key</source>
        <translation>Insira a chave-mestra</translation>
    </message>
    <message>
        <source>Key File:</source>
        <translation>Arquivo-Chave:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Senha:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Navegar</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Não foi possível abrir o banco de dados.</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>Não foi possível abrir o arquivo-chave</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Todos os arquivos</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>Arquivos-chave</translation>
    </message>
    <message>
        <source>Select key file</source>
        <translation>Escolha o arquivo-chave</translation>
    </message>
</context>
<context>
    <name>DatabaseRepairWidget</name>
    <message>
        <source>Repair database</source>
        <translation>Reparar banco de dados</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>Não foi possível abrir arquivo-chave</translation>
    </message>
    <message>
        <source>Database opened fine. Nothing to do.</source>
        <translation>Banco de dados aberto com sucesso. Nada para fazer.</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Não foi possível abrir o banco de dados.</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Sucesso</translation>
    </message>
    <message>
        <source>The database has been successfully repaired
You can now save it.</source>
        <translation>O banco de dados foi reparado com sucesso
Você pode salvá-lo agora.</translation>
    </message>
    <message>
        <source>Unable to repair the database.</source>
        <translation>Não foi possível reparar o banco de dados.</translation>
    </message>
</context>
<context>
    <name>DatabaseSettingsWidget</name>
    <message>
        <source>Database name:</source>
        <translation>Nome do banco de dados:</translation>
    </message>
    <message>
        <source>Database description:</source>
        <translation>Descrição do banco de dados:</translation>
    </message>
    <message>
        <source>Transform rounds:</source>
        <translation>Rodadas de transformação:</translation>
    </message>
    <message>
        <source>Default username:</source>
        <translation>Usuário padrão:</translation>
    </message>
    <message>
        <source>Use recycle bin:</source>
        <translation>Usar lixeira:</translation>
    </message>
    <message>
        <source> MiB</source>
        <translation> MB</translation>
    </message>
    <message>
        <source>Benchmark</source>
        <translation>Benchmark</translation>
    </message>
    <message>
        <source>Max. history items:</source>
        <translation>Máx. itens no histórico:</translation>
    </message>
    <message>
        <source>Max. history size:</source>
        <translation>Tamanho máx. do histórico:</translation>
    </message>
</context>
<context>
    <name>DatabaseTabWidget</name>
    <message>
        <source>Root</source>
        <translation>Raiz</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>Banco de Dados KeePass 2</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Todos os arquivos</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>Abrir banco de dados</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>File not found!</source>
        <translation>Arquivo não localizado!</translation>
    </message>
    <message>
        <source>Open KeePass 1 database</source>
        <translation>Abrir banco de dados KeePass 1</translation>
    </message>
    <message>
        <source>KeePass 1 database</source>
        <translation>Banco de dados KeePass 1</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Todos os arquivos (*)</translation>
    </message>
    <message>
        <source>Close?</source>
        <translation>Fechar?</translation>
    </message>
    <message>
        <source>Save changes?</source>
        <translation>Salvar alterações?</translation>
    </message>
    <message>
        <source>&quot;%1&quot; was modified.
Save changes?</source>
        <translation>&quot;%1&quot; foi modificado.
Salvar alterações?</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>Escrever no banco de dados falhou.</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>Salvar banco de dados como</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>Novo banco de dados</translation>
    </message>
    <message>
        <source>locked</source>
        <translation>trancado</translation>
    </message>
    <message>
        <source>The database you are trying to open is locked by another instance of KeePassX.
Do you want to open it anyway? Alternatively the database is opened read-only.</source>
        <translation>O banco de dados que você está tentando abrir está bloqueado por outra instância do KeePassX.
Você quer abri-lo de qualquer forma? Alternativamente, o banco de dados é aberto como somente leitura.</translation>
    </message>
    <message>
        <source>Lock database</source>
        <translation>Trancar Banco de Dados</translation>
    </message>
    <message>
        <source>Can't lock the database as you are currently editing it.
Please press cancel to finish your changes or discard them.</source>
        <translation>Não é possível trancar o banco de dados uma vez que você o está editando.
Por favor, aperte cancelar para finalizar suas alterações ou descartá-las.</translation>
    </message>
    <message>
        <source>This database has never been saved.
You can save the database or stop locking it.</source>
        <translation>Esse banco de dados nunca foi salvo.
Você pode salvar o banco de dados ou parar de trancá-lo.</translation>
    </message>
    <message>
        <source>This database has been modified.
Do you want to save the database before locking it?
Otherwise your changes are lost.</source>
        <translation>Esse banco de dados foi modificado.
Você deseja salvar o banco de dados antes de travá-lo?
Do contrário, suas alterações serão perdidas.</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is in edit mode.
Discard changes and close anyway?</source>
        <translation>&quot;%1&quot; está em modo de edição.
Descartar alterações e fechar mesmo assim?</translation>
    </message>
    <message>
        <source>Export database to CSV file</source>
        <translation>Exportar banco de dados para arquivo CSV</translation>
    </message>
    <message>
        <source>CSV file</source>
        <translation>Arquivo CSV</translation>
    </message>
    <message>
        <source>Writing the CSV file failed.</source>
        <translation>Falha ao gravar arquivo CSV.</translation>
    </message>
    <message>
        <source>The database you are trying to save as is locked by another instance of KeePassX.
Do you want to save it anyway?</source>
        <translation>O banco de dados que você está tentando salvar como está travado por uma outra instância de KeePassX.
Você deseja salvá-lo mesmo assim?</translation>
    </message>
</context>
<context>
    <name>DatabaseWidget</name>
    <message>
        <source>Change master key</source>
        <translation>Alterar chave mestra</translation>
    </message>
    <message>
        <source>Delete entry?</source>
        <translation>Apagar entrada?</translation>
    </message>
    <message>
        <source>Do you really want to delete the entry &quot;%1&quot; for good?</source>
        <translation>Você realmente quer apagar a entrada &quot;%1&quot; para sempre?</translation>
    </message>
    <message>
        <source>Delete entries?</source>
        <translation>Apagar entradas?</translation>
    </message>
    <message>
        <source>Do you really want to delete %1 entries for good?</source>
        <translation>Você realmente quer apagar %1 entradas para sempre?</translation>
    </message>
    <message>
        <source>Move entries to recycle bin?</source>
        <translation>Mover entradas para lixeira?</translation>
    </message>
    <message numerus="yes">
        <source>Do you really want to move %n entry(s) to the recycle bin?</source>
        <translation><numerusform>Você realmente deseja mover %n entrada para a lixeira?</numerusform><numerusform>Você realmente deseja mover %n entradas para a lixeira?</numerusform></translation>
    </message>
    <message>
        <source>Delete group?</source>
        <translation>Apagar grupo?</translation>
    </message>
    <message>
        <source>Do you really want to delete the group &quot;%1&quot; for good?</source>
        <translation>Você realmente quer apagar o grupo &quot;%1&quot; para sempre?</translation>
    </message>
    <message>
        <source>Current group</source>
        <translation>Grupo atual</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Não foi possível calcular chave mestra</translation>
    </message>
</context>
<context>
    <name>EditEntryWidget</name>
    <message>
        <source>Entry</source>
        <translation>Entrada</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avançado</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>Ícone</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>Auto-Digitação</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propriedades</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Histórico</translation>
    </message>
    <message>
        <source>Entry history</source>
        <translation>Histórico de Entradas</translation>
    </message>
    <message>
        <source>Add entry</source>
        <translation>Adicionar entrada</translation>
    </message>
    <message>
        <source>Edit entry</source>
        <translation>Editar entrada</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>Senhas diferentes fornecidas.</translation>
    </message>
    <message>
        <source>New attribute</source>
        <translation>Novo atributo</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>Selecionar arquivo</translation>
    </message>
    <message>
        <source>Unable to open file</source>
        <translation>Não foi possível abrir o arquivo</translation>
    </message>
    <message>
        <source>Save attachment</source>
        <translation>Salvar anexo</translation>
    </message>
    <message>
        <source>Unable to save the attachment:
</source>
        <translation>Não foi possível salvar o anexo:
</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Amanhã</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation><numerusform>%n semana(s)</numerusform><numerusform>%n semana(s)</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s)</source>
        <translation><numerusform>%n mês</numerusform><numerusform>%n mese(s)</numerusform></translation>
    </message>
    <message>
        <source>1 year</source>
        <translation>1 ano</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAdvanced</name>
    <message>
        <source>Additional attributes</source>
        <translation>Atributos extras</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <source>Attachments</source>
        <translation>Anexos</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAutoType</name>
    <message>
        <source>Enable Auto-Type for this entry</source>
        <translation>Habilitar Auto-Digitação para esta entrada</translation>
    </message>
    <message>
        <source>Inherit default Auto-Type sequence from the group</source>
        <translation>Herdar sequência pré-definida de Auto-Digitação do grupo</translation>
    </message>
    <message>
        <source>Use custom Auto-Type sequence:</source>
        <translation>Usar sequência de Auto-Digitação personalizada:</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Window title:</source>
        <translation>Título da Janela:</translation>
    </message>
    <message>
        <source>Use default sequence</source>
        <translation>Usar sequência pré-definida</translation>
    </message>
    <message>
        <source>Set custom sequence:</source>
        <translation>Definir sequência personalizada:</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetHistory</name>
    <message>
        <source>Show</source>
        <translation>Mostrar</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Restaurar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Delete all</source>
        <translation>Excluir todos</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetMain</name>
    <message>
        <source>Title:</source>
        <translation>Título:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nome de Usuário:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Senha:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>Repetir:</translation>
    </message>
    <message>
        <source>Gen.</source>
        <translation>Gerar</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Expira em</translation>
    </message>
    <message>
        <source>Presets</source>
        <translation>Pré-definidos</translation>
    </message>
    <message>
        <source>Notes:</source>
        <translation>Notas:</translation>
    </message>
</context>
<context>
    <name>EditGroupWidget</name>
    <message>
        <source>Group</source>
        <translation>Grupo</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>Ícone</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propriedades</translation>
    </message>
    <message>
        <source>Add group</source>
        <translation>Adicionar grupo</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>Editar grupo</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Habilitar</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Desabilitar</translation>
    </message>
    <message>
        <source>Inherit from parent group (%1)</source>
        <translation>Herdar do grupo pai (%1)</translation>
    </message>
</context>
<context>
    <name>EditGroupWidgetMain</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>Notas</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Expira em</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Auto-type</source>
        <translation>Auto-digitar</translation>
    </message>
    <message>
        <source>Use default auto-type sequence of parent group</source>
        <translation>Usar sequência de auto-digitação padrão do grupo pai</translation>
    </message>
    <message>
        <source>Set default auto-type sequence</source>
        <translation>Definir sequência auto-digitação padrão</translation>
    </message>
</context>
<context>
    <name>EditWidgetIcons</name>
    <message>
        <source>Use default icon</source>
        <translation>Usar ícone padrão</translation>
    </message>
    <message>
        <source>Use custom icon</source>
        <translation>Usar ícone personalizado</translation>
    </message>
    <message>
        <source>Add custom icon</source>
        <translation>Adicionar ícone personalizado</translation>
    </message>
    <message>
        <source>Delete custom icon</source>
        <translation>Excluir ícone personalizado</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Imagens</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Todos os arquivos</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>Selecionar imagem</translation>
    </message>
    <message>
        <source>Can&apos;t delete icon!</source>
        <translation>Não é possível apagar o ícone!</translation>
    </message>
    <message numerus="yes">
        <source>Can&apos;t delete icon. Still used by %n item(s).</source>
        <translation><numerusform>Não é possível apagar o ícone. Ainda usado por %n item.</numerusform><numerusform>Não é possível apagar o ícone. Ainda usado por %n itens.</numerusform></translation>
    </message>
</context>
<context>
    <name>EditWidgetProperties</name>
    <message>
        <source>Created:</source>
        <translation>Criado em:</translation>
    </message>
    <message>
        <source>Modified:</source>
        <translation>Modificado em:</translation>
    </message>
    <message>
        <source>Accessed:</source>
        <translation>Acessado em:</translation>
    </message>
    <message>
        <source>Uuid:</source>
        <translation>Uuid:</translation>
    </message>
</context>
<context>
    <name>EntryAttributesModel</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
</context>
<context>
    <name>EntryHistoryModel</name>
    <message>
        <source>Last modified</source>
        <translation>Modificado pela última vez em</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de usuário</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
</context>
<context>
    <name>EntryModel</name>
    <message>
        <source>Group</source>
        <translation>Grupo</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de usuário</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
</context>
<context>
    <name>Group</name>
    <message>
        <source>Recycle Bin</source>
        <translation>Lixeira</translation>
    </message>
</context>
<context>
    <name>KeePass1OpenWidget</name>
    <message>
        <source>Import KeePass1 database</source>
        <translation>Importar banco de dados KeePass1</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Não foi possível abrir o banco de dados.</translation>
    </message>
</context>
<context>
    <name>KeePass1Reader</name>
    <message>
        <source>Unable to read keyfile.</source>
        <translation>Não foi possível ler o arquivo-chave.</translation>
    </message>
    <message>
        <source>Not a KeePass database.</source>
        <translation>Não é um banco de dados KeePass.</translation>
    </message>
    <message>
        <source>Unsupported encryption algorithm.</source>
        <translation>Algoritmo de encriptação não suportado.</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>Versão do banco de dados KeePass não suportada.</translation>
    </message>
    <message>
        <source>Root</source>
        <translation>Raíz</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Não foi possível calcular a chave mestra</translation>
    </message>
</context>
<context>
    <name>KeePass2Reader</name>
    <message>
        <source>Not a KeePass database.</source>
        <translation>Não é um banco de dados KeePass.</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>Versão não suportada do banco de dados KeePass.</translation>
    </message>
    <message>
        <source>Wrong key or database file is corrupt.</source>
        <translation>Chave errada ou arquivo de banco de dados está corrompido.</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Não foi possível calcular a chave mestre</translation>
    </message>
    <message>
        <source>The selected file is an old KeePass 1 database (.kdb).

You can import it by clicking on Database &gt; 'Import KeePass 1 database'.
This is a one-way migration. You won&apos;t be able to open the imported database with the old KeePassX 0.4 version.</source>
        <translation>O arquivo selecionado é um banco de dados antigo do KeePass 1 (.kdb).

Você pode importá-lo clicando em Banco de Dados &gt; &apos;Importar banco de dados KeePass 1&apos;.
Esta é uma migração de uma via. Você não poderá abrir o banco de dados importado com a versão antiga do KeePassX 0.4.</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Fatal error while testing the cryptographic functions.</source>
        <translation>Erro fatal enquanto testava as funções criptográficas.</translation>
    </message>
    <message>
        <source>KeePassX - Error</source>
        <translation>KeePassX - Erro</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Database</source>
        <translation>Banco de Dados</translation>
    </message>
    <message>
        <source>Recent databases</source>
        <translation>Bancos de dados recentes</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Entries</source>
        <translation>Entradas</translation>
    </message>
    <message>
        <source>Copy attribute to clipboard</source>
        <translation>Copiar atributo para a área de transferência</translation>
    </message>
    <message>
        <source>Groups</source>
        <translation>Grupos</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>Abrir banco de dados</translation>
    </message>
    <message>
        <source>Save database</source>
        <translation>Salvar banco de dados</translation>
    </message>
    <message>
        <source>Close database</source>
        <translation>Fechar banco de dados</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>Novo banco de dados</translation>
    </message>
    <message>
        <source>Add new entry</source>
        <translation>Adicionar nova entrada</translation>
    </message>
    <message>
        <source>View/Edit entry</source>
        <translation>Ver/Editar entrada</translation>
    </message>
    <message>
        <source>Delete entry</source>
        <translation>Excluir entrada</translation>
    </message>
    <message>
        <source>Add new group</source>
        <translation>Adicionar novo grupo</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>Editar grupo</translation>
    </message>
    <message>
        <source>Delete group</source>
        <translation>Excluir grupo</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>Salvar banco de dados como</translation>
    </message>
    <message>
        <source>Change master key</source>
        <translation>Alterar chave-mestra</translation>
    </message>
    <message>
        <source>Database settings</source>
        <translation>Configurações do Banco de Dados</translation>
    </message>
    <message>
        <source>Import KeePass 1 database</source>
        <translation>Importar banco de dados KeePass1</translation>
    </message>
    <message>
        <source>Clone entry</source>
        <translation>Clonar entrada</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Localizar</translation>
    </message>
    <message>
        <source>Copy username to clipboard</source>
        <translation>Copiar nome de usuário para área de transferência</translation>
    </message>
    <message>
        <source>Copy password to clipboard</source>
        <translation>Copiar senha para área de transferência</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>Perform Auto-Type</source>
        <translation>Realizar Auto-Digitação</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation>Abrir URL</translation>
    </message>
    <message>
        <source>Lock databases</source>
        <translation>Trancar bancos de dados</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>Notas</translation>
    </message>
    <message>
        <source>Show toolbar</source>
        <translation>Mostrar barra de ferramentas</translation>
    </message>
    <message>
        <source>read-only</source>
        <translation>somente leitura</translation>
    </message>
    <message>
        <source>Toggle window</source>
        <translation>Alternar Janela</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Ferramentas</translation>
    </message>
    <message>
        <source>Copy username</source>
        <translation>Copiar nome de usuário</translation>
    </message>
    <message>
        <source>Copy password</source>
        <translation>Copiar senha</translation>
    </message>
    <message>
        <source>Export to CSV file</source>
        <translation>Exportar para arquivo CSV</translation>
    </message>
    <message>
        <source>Repair database</source>
        <translation>Reparar banco de dados</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>Banco de dados Keepass 2</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Todos arquivos</translation>
    </message>
    <message>
        <source>Save repaired database</source>
        <translation>Salvar banco de dados reparado</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>Escrita do banco de dados falhou.</translation>
    </message>
</context>
<context>
    <name>PasswordGeneratorWidget</name>
    <message>
        <source>Password:</source>
        <translation>Senha:</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Tamanho:</translation>
    </message>
    <message>
        <source>Character Types</source>
        <translation>Tipos de Caracteres</translation>
    </message>
    <message>
        <source>Upper Case Letters</source>
        <translation>Letras Maiúsculas</translation>
    </message>
    <message>
        <source>Lower Case Letters</source>
        <translation>Letras Minúsculas</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>Números</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>Caracteres Especiais</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>Excluir caracteres similares</translation>
    </message>
    <message>
        <source>Ensure that the password contains characters from every group</source>
        <translation>Assegurar que a senha contenha caracteres de todos os grupos</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Aceitar</translation>
    </message>
</context>
<context>
    <name>QCommandLineParser</name>
    <message>
        <source>Displays version information.</source>
        <translation>Mostrar informações da versão.</translation>
    </message>
    <message>
        <source>Displays this help.</source>
        <translation>Mostrar esta ajuda.</translation>
    </message>
    <message>
        <source>Unknown option &apos;%1&apos;.</source>
        <translation>Opção desconhecida &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Unknown options: %1.</source>
        <translation>Opções desconhecidas: %1.</translation>
    </message>
    <message>
        <source>Missing value after &apos;%1&apos;.</source>
        <translation>Falta valor após &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Unexpected value after &apos;%1&apos;.</source>
        <translation>Valor inesperado após &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>[options]</source>
        <translation>[opções]</translation>
    </message>
    <message>
        <source>Usage: %1</source>
        <translation>Utilização: %1</translation>
    </message>
    <message>
        <source>Options:</source>
        <translation>Opções:</translation>
    </message>
    <message>
        <source>Arguments:</source>
        <translation>Argumentos:</translation>
    </message>
</context>
<context>
    <name>QSaveFile</name>
    <message>
        <source>Existing file %1 is not writable</source>
        <translation>O arquivo existente %1 não é gravável</translation>
    </message>
    <message>
        <source>Writing canceled by application</source>
        <translation>Escrita cancelada pelo aplicativo</translation>
    </message>
    <message>
        <source>Partial write. Partition full?</source>
        <translation>Escrita parcial. Partição cheia?</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor</name>
    <message>
        <source>Internal zlib error when compressing: </source>
        <translation>Erro interno do zlib ao compactar: </translation>
    </message>
    <message>
        <source>Error writing to underlying device: </source>
        <translation>Erro ao gravar no dispositivo subjacente: </translation>
    </message>
    <message>
        <source>Error opening underlying device: </source>
        <translation>Erro ao abrir dispositivo subjacente: </translation>
    </message>
    <message>
        <source>Error reading data from underlying device: </source>
        <translation>Erro ao ler dados do dispositivo subjacente: </translation>
    </message>
    <message>
        <source>Internal zlib error when decompressing: </source>
        <translation>Erro interno do zlib ao descompactar: </translation>
    </message>
</context>
<context>
    <name>QtIOCompressor::open</name>
    <message>
        <source>The gzip format not supported in this version of zlib.</source>
        <translation>Sem suporte ao formato gzip nesta versão do zlib.</translation>
    </message>
    <message>
        <source>Internal zlib error: </source>
        <translation>Erro interno do zlib: </translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <source>Find:</source>
        <translation>Localizar:</translation>
    </message>
    <message>
        <source>Case sensitive</source>
        <translation>Diferenciar maiúsculas e minúsculas</translation>
    </message>
    <message>
        <source>Current group</source>
        <translation>Grupo atual</translation>
    </message>
    <message>
        <source>Root group</source>
        <translation>Grupo Raiz</translation>
    </message>
</context>
<context>
    <name>SettingsWidget</name>
    <message>
        <source>Application Settings</source>
        <translation>Configurações do Aplicativo</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Segurança</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetGeneral</name>
    <message>
        <source>Remember last databases</source>
        <translation>Lembrar dos últimos bancos de dados</translation>
    </message>
    <message>
        <source>Open previous databases on startup</source>
        <translation>Abrir bancos de dados anteriores na inicialização</translation>
    </message>
    <message>
        <source>Automatically save on exit</source>
        <translation>Salvar automaticamente ao sair</translation>
    </message>
    <message>
        <source>Automatically save after every change</source>
        <translation>Salvar automaticamente depois de cada alteração</translation>
    </message>
    <message>
        <source>Minimize when copying to clipboard</source>
        <translation>Minimizar ao copiar para área de transferência</translation>
    </message>
    <message>
        <source>Use group icon on entry creation</source>
        <translation>Usar ícone de grupo na criação da entrada</translation>
    </message>
    <message>
        <source>Global Auto-Type shortcut</source>
        <translation>Atalho para Auto-Digitação Global</translation>
    </message>
    <message>
        <source>Use entry title to match windows for global auto-type</source>
        <translation>Usar título da entrada para comparar janelas para auto-digitação global</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Idioma</translation>
    </message>
    <message>
        <source>Show a system tray icon</source>
        <translation>Mostrar um ícone da bandeja do sistema</translation>
    </message>
    <message>
        <source>Hide window to system tray when minimized</source>
        <translation>Ocultar janela na bandeja de sistema quando minimizada</translation>
    </message>
    <message>
        <source>Remember last key files</source>
        <translation>Lembrar dos últimos arquivos-chave</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetSecurity</name>
    <message>
        <source>Clear clipboard after</source>
        <translation>Limpar área de transferência após</translation>
    </message>
    <message>
        <source> sec</source>
        <translation> seg</translation>
    </message>
    <message>
        <source>Lock databases after inactivity of</source>
        <translation>Travar bancos de dados após inatividade de</translation>
    </message>
    <message>
        <source>Show passwords in cleartext by default</source>
        <translation>Mostrar senhas em texto claro por padrão</translation>
    </message>
    <message>
        <source>Always ask before performing auto-type</source>
        <translation>Sempre perguntar antes de realizar auto-digitação</translation>
    </message>
</context>
<context>
    <name>UnlockDatabaseWidget</name>
    <message>
        <source>Unlock database</source>
        <translation>Destrancar banco de dados</translation>
    </message>
</context>
<context>
    <name>WelcomeWidget</name>
    <message>
        <source>Welcome!</source>
        <translation>Bem-vindo!</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>KeePassX - cross-platform password manager</source>
        <translation>KeePassX - gerenciador de senhas multiplataforma</translation>
    </message>
    <message>
        <source>filename of the password database to open (*.kdbx)</source>
        <translation>nome de arquivo do banco de dados de senhas a ser aberto (*.kdbx)</translation>
    </message>
    <message>
        <source>path to a custom config file</source>
        <translation>caminho para um arquivo de configuração personalizado</translation>
    </message>
    <message>
        <source>key file of the database</source>
        <translation>arquivo-chave do banco de dados</translation>
    </message>
</context>
</TS>